package controller;

import simulator.*;

/**
 * The control logic for the PhoneDrone.
 *
 * @author CS159 Professors, James Madison University
 * @version 1.0
 */
public class FoneDroneController extends DroneController {

    private int[] location;

    /**
     * Explicit Value Constructor.
     *
     * @param number The phone number to look for
     */
    public FoneDroneController(String number) {
        super(number);
        this.location = null;
    }

    /**
     * Get the location of the phone (or null if it hasn't been found).
     * 
     * @return The location of the phone (or null)
     */
    public int[] getLocationOfPhone() {
        return location;
    }

    /**
     * Start the FoneDrone.
     */
    @Override
    public void start() {
        search();
    }
    /**
     * Search (recursively).
     */
    private void search() {
        if (location == null)
            location = drone.checkForPhone(number);

        Direction next = getNextDirection();

        // The base case
        if (next == null)
            return;

        // Refinement
        do {
            drone.move(next);
            search();
            drone.move(next.opposite());

            next = getNextDirection();

        } while (next != null);
    }

    /**
     * Get the next direction to search in.
     * 
     * @return The next direction
     */
    private Direction getNextDirection() {

        for (Direction d : Direction.values()) {
            if ((location == null) && drone.canMove(d) && !drone.hasBeen(d))
            return d;
        }
        return null;
    }
}
